import { Drawer, PageHeader } from 'antd'
import type { DrawerProps } from 'antd'
import type { PropsWithChildren, FC } from 'react'
import styles from './index.less'
type AnimateContentProps = {
  visible: boolean
  onVisibleChange: (visible: boolean) => void
  disableBreadcrumb?: boolean
} & Omit<DrawerProps, 'visible' | 'onVisibleChange'>

const AnimateContent: FC<PropsWithChildren<AnimateContentProps>> = ({
  visible,
  onVisibleChange,
  children,
  title,
  ...others
}) => {
  const wrapHeight = document.querySelector('.ant-pro-page-container-warp')?.clientHeight || 0

  return (
    <div className={styles.pageContainer}>
      <Drawer
        {...others}
        title={<PageHeader title={title} onBack={() => onVisibleChange(false)} />}
        getContainer={false}
        visible={visible}
        push={false}
        onClose={() => onVisibleChange(false)}
        mask={false}
        width="calc(100vw - 256px)"
        style={{ right: '24px', top: `${72 + wrapHeight}px` }}
        contentWrapperStyle={{
          height: `calc(100vh - 96px - ${wrapHeight}px)`
        }}
        // closeIcon={<Button onClick={() => onVisibleChange(false)}>返回</Button>}>
      >
        {visible ? children : null}
      </Drawer>
    </div>
  )
}

export default AnimateContent
