import { useState, useEffect, useContext } from 'react'
import { Button, Drawer, Radio, Tag } from 'antd'
import { Actions, FlowContext } from '../../context'
import type { RadioChangeEvent } from 'antd'
import { ApprovalMethod, ApprovalType } from '../../enum'
import TreeNodeSelect from '@/pages/Project/Management/components/TreeNodeSelect'

const FlowDrawer = () => {
  const { flowState, dispatch } = useContext(FlowContext)
  const { drawerConfig } = flowState

  const [state, setState] = useState({
    approvalType: ApprovalType.TARGET,
    fetching: false,
    options: [],
    staffOptions: []
  })
  useEffect(() => {
    if (drawerConfig.nodeId && drawerConfig.visible) {
      const defaultStaffIds = flowState.flowData.get(drawerConfig.nodeId)?.approvalAccounts || []
      setState({ ...state, staffOptions: defaultStaffIds })
    }
  }, [drawerConfig])

  const handleCancel = () => dispatch({ type: Actions.CLOSE_MODAL })

  const plainOptions = [
    { label: '指定账号', value: ApprovalType.TARGET }
    // { label: '上级', value: ApprovalType.SUPERIOR },
    // { label: '角色', value: ApprovalType.ROLE },
    // { label: '发起人自选', value: ApprovalType.INITIATOR },
    // { label: '连续多级上级', value: ApprovalType.MULTISTAGE }
  ]

  const approvalTypeChange = (e: RadioChangeEvent) => {
    const { target } = e
    if (target?.value) {
      setState({ ...state, approvalType: target.value })
    }
  }

  const staffIds = state.staffOptions.map(i => i.value)
  const triggerChange = (val, option) => {
    if (!staffIds.includes(val)) {
      setState({
        ...state,
        staffOptions: [option].map(item => ({ ID: item.value, name: item.label }))
      })
    }
  }

  const handleOnOk = () => {
    const payload = {
      id: drawerConfig.nodeId,
      node: {
        approvalType: state.approvalType,
        approvalAccounts: state.staffOptions,
        approvalMethod: ApprovalMethod.ORDER
      }
    }
    dispatch({
      type: Actions.SET_FLOW_NODE,
      payload
    })
    handleCancel()
  }

  return (
    <Drawer
      visible={drawerConfig.visible}
      onClose={handleCancel}
      destroyOnClose
      footer={
        <div className="flex justify-end">
          <Button onClick={handleCancel}>取消</Button>
          <Button className="ml-8px" type="primary" onClick={handleOnOk}>
            确认
          </Button>
        </div>
      }
      title={<span className="font-medium">设置审批人</span>}
      width="30%"
    >
      <div>
        <Radio.Group
          options={plainOptions}
          onChange={approvalTypeChange}
          value={state.approvalType}
        />
        <div className="mt-40px flex flex-col">
          <div className="text-sm mb-4">
            <span className="font-medium mr-1 text-14px">添加员工</span>
            {/* <span className="text-hex-000000 text-opacity-45">不得超过20人</span> */}
          </div>
          <TreeNodeSelect onChange={triggerChange} />
          {/* <Select
            showSearch
            disabled={state.staffOptions.length}
            value={null}
            onChange={triggerChange}
            filterOption={false}
            onSearch={v => debounceFetcher({ search: v })}
            notFoundContent={state.fetching ? <Spin size="small" /> : null}
            options={state.options?.filter(item => !staffIds.includes(item.value))}
          /> */}
          <div className="mt-4">
            {state.staffOptions.map(item => (
              <Tag key={item.ID}>{item.name}</Tag>
            ))}
          </div>
        </div>
      </div>
    </Drawer>
  )
}

export default FlowDrawer
