import { buildUUID } from '@/utils/uuid'
import { BranchesOutlined, PlusOutlined, SolutionOutlined } from '@ant-design/icons'
import { Button, Popover } from 'antd'
import React, { useMemo, useState, useContext } from 'react'
import { getBezierPath, getEdgeCenter, getMarkerEnd, useStoreState } from 'react-flow-renderer'
import { Actions, FlowContext } from '../../context'
import { generateElements, genreateElementEnum, getEdgeParams } from '../../utils'
import styles from './index.less'
import 'antd/lib/button/style/css'
const foreignObjectSize = 50

const renderMenu = ({ dispatch, elements, togglePopver, id, flowInstance }) => {
  const setElements = els => {
    dispatch({
      type: Actions.SET_ELEMENTS,
      payload: els
    })
  }
  const edit = () => {
    togglePopver(false)
    // dispatch({
    //   type: Actions.OPEN_MODAL,
    //   payload: {
    //     id: node.id,
    //     type: 'relation'
    //   }
    // })
  }
  const remove = () => {
    dispatch({
      type: Actions.REMOVE_FLOW_NODE,
      payload: node
    })
  }

  const addAuditor = () => {
    // console.log(buildUUID())
    const uid = buildUUID()
    const newNode = {
      id: uid,
      type: 'input',
      // position: { x: 400, y: 0 },
      data: {}
    }
    const currentEdge = elements.find(item => item.id === id)
    setElements(generateElements(genreateElementEnum.ADD, elements)(newNode, currentEdge))
    dispatch({
      type: Actions.SET_FLOW_NODE,
      payload: {
        id: uid,
        node: null
      }
    })
    togglePopver(false)
    setTimeout(() => {
      flowInstance?.fitView()
    }, 80)
  }

  return (
    // <Menu>
    //   <Menu.Item key="1" onClick={addAuditor}>
    //     <ClusterOutlined />
    //     <span className="ml-1">审批人</span>
    //   </Menu.Item>
    //   {/* <Menu.Item key="2" onClick={remove}>
    //     <ApartmentOutlined />
    //     <span className="ml-1">条件分支</span>
    //   </Menu.Item> */}
    // </Menu>
    <ul className="m-0 p-0 ">
      <li>
        <Button type="dashed" onClick={addAuditor} icon={<SolutionOutlined />}>
          审批人
        </Button>
      </li>
      {/* <li className="mt-2 condition">
        <Button type="dashed" onClick={addAuditor} icon={<BranchesOutlined />}>
          条件分支
        </Button>
      </li> */}
    </ul>
    //   <ul className="m-0 p-0">
    //   <li className="rounded-2px border border-hex-d9d9d9 border-dashed text-hex-1890ff px-17px py-9px cursor-pointer">
    //     <SolutionOutlined />
    //     <span className="ml-9px">审批人</span>
    //   </li>
    //   <li className="mt-2 rounded-2px border border-hex-d9d9d9 border-dashed text-hex-52c41a px-17px py-9px cursor-pointer">
    //     <BranchesOutlined />
    //     <span className="ml-9px">条件分支</span>
    //   </li>
    // </ul>
  )
}

export function CommonEdge(props) {
  const {
    id,
    sourceX,
    sourceY,
    targetX,
    targetY,
    source,
    target,
    style = {},
    arrowHeadType,
    markerEndId
  } = props

  const [visible, setVisible] = useState(false)
  const { flowState, dispatch } = useContext(FlowContext)
  const { elements, flowInstance } = flowState
  const nodes = useStoreState(store => store.nodes)
  const markerEnd = getMarkerEnd(arrowHeadType, markerEndId)

  const sourceNode = useMemo(() => nodes.find(n => n.id === source), [source, nodes])
  const targetNode = useMemo(() => nodes.find(n => n.id === target), [target, nodes])

  if (!sourceNode || !targetNode) {
    return null
  }

  const { sx, sy, tx, ty, sourcePos, targetPos } = getEdgeParams(sourceNode, targetNode)

  const d = getBezierPath({
    sourceX: sx,
    sourceY: sy - 2,
    sourcePosition: sourcePos,
    targetPosition: targetPos,
    targetX: tx,
    targetY: ty
  })
  const [edgeCenterX, edgeCenterY] = getEdgeCenter({
    sourceX,
    sourceY,
    targetX,
    targetY
  })

  const togglePopver = (isShow: boolean) => {
    setVisible(isShow)
  }

  const onEdgeClick = (evt, id) => {
    togglePopver(true)
    // evt.stopPropagation()
    // alert(`remove ${id}`)
  }

  return (
    <>
      <path id={id} style={style} className={styles.flowPath} d={d} markerEnd={markerEnd} />
      <foreignObject
        width={foreignObjectSize}
        height={foreignObjectSize}
        x={edgeCenterX - foreignObjectSize / 2}
        y={edgeCenterY - foreignObjectSize / 2}>
        <div className={styles.addIcon}>
          <Popover
            content={renderMenu({ elements, dispatch, togglePopver, id, flowInstance })}
            trigger="click"
            placement="right"
            visible={visible}
            destroyTooltipOnHide
            onVisibleChange={togglePopver}
            overlayClassName="flow-popover">
            <Button
              icon={<PlusOutlined />}
              shape="circle"
              size="small"
              onClick={event => onEdgeClick(event, id)}
            />
          </Popover>
        </div>
      </foreignObject>
    </>
  )
}
