import React, { useContext, useEffect } from 'react'
import ReactFlow, { Background, MiniMap, Controls } from 'react-flow-renderer'
import { Actions, FlowContext, initialElements } from '../../context'

import type { Elements, NodeTypesType, EdgeTypesType } from 'react-flow-renderer'
import { CommonNode, InputNode, OutputNode } from '../Node'
import { CommonEdge } from '../Edge'
import type { ApprovalMethod, ApprovalType } from '../../enum'

const nodeTypes: NodeTypesType = {
  start: InputNode,
  end: OutputNode,
  common: CommonNode
}

const edgeTypes: EdgeTypesType = {
  common: CommonEdge
}

type flowProcessDataItem = {
  approvalType: ApprovalType
  approvalMethod: ApprovalMethod
  approvalAccounts: { ID: string; name: string }[]
}

type FlowGrophProps = {
  id: string
  flowProcess?: Elements
  flowProcessData?: Record<string, flowProcessDataItem>
}
const FlowGroph: React.FC<FlowGrophProps> = ({ id, flowProcess, flowProcessData }) => {
  const { flowState, dispatch } = useContext(FlowContext)
  useEffect(() => {
    if (id) {
      if (flowProcess?.length) {
        dispatch({
          type: Actions.SET_ELEMENTS,
          payload: flowProcess
        })
        dispatch({
          type: Actions.SET_FLOW_NODE,
          payload: new Map(Object.entries(flowProcessData))
        })
      } else {
        dispatch({
          type: Actions.SET_ELEMENTS,
          payload: initialElements
        })

        dispatch({
          type: Actions.SET_FLOW_NODE,
          payload: new Map()
        })
      }
    }
  }, [id])
  const { elements } = flowState

  const defaultOptions = {
    nodesDraggable: false, // 不可拖拽
    // zoomOnScroll: false, // 使用鼠标滚轮或触控板放大和缩小图形
    zoomOnPinch: false, // 使用捏合放大和缩小图形
    // snapToGrid: true,
    onLoad: reactFlowInstance => {
      dispatch({
        type: Actions.SET_FLOW_INSTANCE,
        payload: reactFlowInstance
      })
      setTimeout(() => {
        reactFlowInstance?.fitView()
      }, 0)
    }
  }

  const controlsOptions = {
    showZoom: true,
    showFitView: false,
    showInteractive: false
  }
  return (
    <ReactFlow {...defaultOptions} elements={elements} nodeTypes={nodeTypes} edgeTypes={edgeTypes}>
      <MiniMap />
      <Background />
      <Controls {...controlsOptions} />
    </ReactFlow>
  )
}

export default FlowGroph
