import React, { createContext, useReducer } from 'react'
import reducer from './reducer'
import { Actions } from '../enum'

import type { Elements, OnLoadParams } from 'react-flow-renderer'
import { ArrowHeadType } from 'react-flow-renderer'

const FlowContext = createContext()

type InitialState = {
  elements: Elements
  flowInstance?: OnLoadParams | null
  flowData: Map<string, any>
  modalConfig: {
    visible: boolean
    nodeType: string
    nodeType: string
  }
}

export const initialElements = [
  {
    id: '89e43a46-88da-4243-ad0b-3c701819ff63',
    type: 'start',
    position: { x: 500, y: 0 },
    data: { sort: 0 }
  },

  {
    id: '83282d24-22d9-4bd8-a6bf-71d6df94f29e',
    type: 'end',
    position: { x: 500, y: 200 },
    data: { sort: 1 }
  },

  {
    id: '29b4469f-9522-4688-8a35-a57ca4875a7a',
    source: '89e43a46-88da-4243-ad0b-3c701819ff63',
    target: '83282d24-22d9-4bd8-a6bf-71d6df94f29e',
    type: 'common',
    arrowHeadType: ArrowHeadType.Arrow
  }
]
const initialState: InitialState = {
  // node节点或者是edge
  elements: initialElements,
  flowData: new Map(),
  drawerConfig: {
    visible: false,
    nodeType: '',
    nodeId: ''
  },
  flowInstance: null
}

const FlowContextProvider = props => {
  const { children } = props
  const [flowState, dispatch] = useReducer(reducer, initialState)
  return <FlowContext.Provider value={{ flowState, dispatch }}>{children}</FlowContext.Provider>
}

export { FlowContext, FlowContextProvider, Actions }
