// context/reducer.js
// import { removeElements } from 'react-flow-renderer'

import type { Elements } from 'react-flow-renderer'
import { Actions } from '../enum'
import { generateElements, genreateElementEnum } from '../utils'

export enum ProcessType {
  NODE = '1'
}
const setElements = (state, elements: Elements) => ({
  ...state,
  elements: Array.isArray(elements) ? elements : []
})

const setFlowNode = (state, payload) => {
  const res = { ...state }
  if (payload instanceof Map) {
    res.flowData = payload
    return res
  }
  const { id, node } = payload
  if (!id) return state

  res.flowData.set(id, node)
  return res
}

const setFlowInstance = (state, flowInstance) => {
  if (flowInstance) {
    return { ...state, flowInstance }
  }
  return state
}

const removeFlowNode = (state, node) => {
  const { id } = node
  const { flowData, elements } = state
  const res = { ...state }
  if (flowData.get(id)) {
    res.elements = generateElements(genreateElementEnum.DEL, elements)(node)
    flowData.delete(id)
  }
  return res
}

const openModal = (state, node) => {
  return node?.id
    ? {
        ...state,
        drawerConfig: {
          visible: true,
          nodeType: node.type,
          nodeId: node.id
        }
      }
    : state
}

const closeModal = state => ({
  ...state,
  drawerConfig: {
    visible: false,
    nodeType: '',
    nodeId: ''
  }
})

// 管理所有处理函数
const handlerMap = {
  [Actions.SET_FLOW_NODE]: setFlowNode,
  [Actions.REMOVE_FLOW_NODE]: removeFlowNode,
  [Actions.OPEN_MODAL]: openModal,
  [Actions.CLOSE_MODAL]: closeModal,
  [Actions.SET_ELEMENTS]: setElements,
  [Actions.SET_FLOW_INSTANCE]: setFlowInstance
}

const reducer = (state, action) => {
  const { type, payload } = action
  const handler = handlerMap[type]
  const res = typeof handler === 'function' && handler(state, payload)
  return res || state
}

export default reducer
