import ProTable from '@ant-design/pro-table'
import React, { useState, useEffect, useRef } from 'react'
import { Button } from 'antd'
import consts from '@/utils/consts'
// import { history } from 'umi'
import { connect } from 'umi'
import dayjs from 'dayjs'
import { queryAcountList } from '@/services/api/institution'
import StaffDetail from '@/pages/Institutions/Staff/components/StaffDetail'
import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import type { InstitutionsModelState } from '@/pages/Institutions/model'
import { generateColumns } from '@/utils/util'
import { genderEum } from '@/pages/Institutions/Staff'
import AnimateContent from '@/components/AnimateContent'
import { ModalType } from '@/utils/enum'

type ListProps = ConnectProps & {
  accountType: API.AccountType[]
}
const Staff: React.FC<ListProps> = ({ schema, dataID, dispatch, accountTypeList }) => {
  const tRef = useRef<ActionType>(null)
  // console.log(accountTypeList)

  useEffect(() => {
    if (!accountTypeList.length) {
      dispatch({
        type: 'institutions/queryAccountTypeList'
      })
    }
    dispatch({
      type: 'schemaBase/querySchema',
      payload: {
        columnType: BaseMenuEnum.STAFF
      }
    })
  }, [])
  const [state, setState] = useState({
    params: {
      search: null,
      accountType: '1',
      dataID
    },
    title: '',
    visible: false,
    currentModalType: ModalType.ADD,
    defaultFormData: {}
  })
  const columns = [
    {
      dataIndex: 'account',
      title: '帐号'
    },
    {
      dataIndex: 'name',
      title: '姓名'
    },
    // {
    //   dataIndex: 'password',
    //   key: 'password',
    //   title: '密码'
    // },
    {
      dataIndex: 'gender',
      key: 'gender',
      title: '性别',
      render: (_, { gender }) => {
        return <span>{genderEum[gender]}</span>
      }
    },
    {
      dataIndex: 'organizationalStructureID',
      key: 'organizationalStructureID',
      title: '组织架构',
      renderText: (_, record) => record.organizationalStructure?.name
    },
    {
      dataIndex: 'institutionID',
      key: 'institutionID',
      title: '所属企事业单位',
      renderText: (_, record) => record.institution.name
    },
    {
      dataIndex: 'phone',
      key: 'phone',
      title: '手机'
    },
    {
      dataIndex: 'createdTime',
      key: 'createdTime',
      title: '创建时间',
      renderText: text => dayjs(text * 1000).format('YYYY-MM-DD')
    },
    {
      dataIndex: 'created',
      key: 'created',
      title: '创建人'
    },
    {
      dataIndex: 'accountType',
      key: 'accountType',
      title: '账号类型',
      filters: true,
      filterMultiple: false,
      valueEnum: accountTypeList.reduce((prev, curr) => {
        const items = { ...prev }
        items[curr.value] = {
          text: curr.label
        }
        return items
      }, {})
    },
    {
      title: '操作',
      dataIndex: 'operation',
      render: (_, record) => (
        <div className="divide-x divide-bg-gray-400 flex flex-row">
          <div
            className="pr-2 text-primary cursor-pointer hover:text-hex-967bbd"
            onClick={() => {
              setState({
                ...state,
                visible: true,
                currentModalType: ModalType.UPDATE,
                title: record.name,
                defaultFormData: {
                  dataID: record.ID,
                  institutionID: record.institution.ID,
                  institutionDisable: true
                }
              })
            }}>
            编辑
          </div>
        </div>
      )
    }
  ]
  return (
    <div>
      <ProTable<API.AccountListItem>
        rowKey="ID"
        params={state.params}
        actionRef={tRef}
        scroll={{ y: document.body.clientHeight - 314 }}
        columns={generateColumns(columns, schema)}
        search={false}
        request={async (params, filter, sorter) => {
          const { code = -1, data: { items = [], totle = 0 } = {} } = await queryAcountList({
            ...params,
            ...filter,
            ...sorter
          })
          return {
            data: items,
            success: code === consts.RET_CODE.SUCCESS,
            totle
          }
        }}
        toolbar={{
          search: {
            onSearch: val => setState({ ...state, params: { ...state.params, search: val } })
          },
          actions: [
            <Button
              type="primary"
              onClick={() => {
                setState({
                  ...state,
                  visible: true,
                  currentModalType: ModalType.ADD,
                  institutionDisable: true,
                  title: '',
                  defaultFormData: {
                    institutionID: dataID,
                    institutionDisable: true
                  }
                })
              }}>
              添加人员
            </Button>
          ]
        }}
      />
      <AnimateContent
        title={
          <>
            {state.currentModalType === ModalType.ADD ? '新增账号' : null}
            {state.currentModalType === ModalType.UPDATE ? `编辑账号(${state.title})` : null}
          </>
        }
        visible={state.visible}
        onVisibleChange={visible => setState({ ...state, visible })}>
        <StaffDetail
          visible={state.visible}
          onVisibleChange={(visible: boolean) => setState({ ...state, visible })}
          type={state.currentModalType}
          defaultFormData={{ ...state.defaultFormData }}
          accountTypeList={accountTypeList}
          reload={() => tRef.current?.reload()}
        />
      </AnimateContent>
    </div>
  )
}

export default connect(
  ({
    institutions,
    schemaBase
  }: {
    institutions: InstitutionsModelState
    schemaBase: SchemaBaseModelState
  }) => ({
    accountTypeList: institutions.accountType.map(item => ({
      label: item.name,
      value: item.value
    })),
    schema: schemaBase.base[BaseMenuEnum.STAFF]?.schema
  })
)(Staff)
