// import { GridContent } from '@ant-design/pro-layout'
import React, { useState, useRef, useLayoutEffect } from 'react'
import { Menu } from 'antd'
import Staff from './components/Staff'
import Organization from './components/Organization'
// import Role from './components/Role'
// import styles from './style.less'
import type { RouteComponentProps } from 'react-router'
import { PageContainer } from '@ant-design/pro-layout'

const { Item } = Menu

type CompanyNameState = {
  mode: 'inline' | 'horizontal'
  selectKey: CompanyNameStateKeys
}
export enum TabEnum {
  STAFF = '0',
  ORGANIZATION = '1',
  ROLE = '2'
}

type CompanyDetailProps = RouteComponentProps

const CompanyDetail: React.FC<CompanyDetailProps> = ({ location }) => {
  const { dataID, structureType, name } = location.state

  const menuMap: Record<string, string> = {
    [TabEnum.STAFF]: '人员管理',
    [TabEnum.ORGANIZATION]: '组织架构'
    // [TabEnum.ROLE]: '角色权限'
  }
  const [initConfig, setInitConfig] = useState<CompanyNameState>({
    mode: 'inline',
    selectKey: TabEnum.STAFF
  })
  const dom = useRef<HTMLDivElement>()
  const resize = () => {
    requestAnimationFrame(() => {
      if (!dom.current) {
        return
      }
      let mode: 'inline' | 'horizontal' = 'inline'
      const { offsetWidth } = dom.current
      if (dom.current.offsetWidth < 641 && offsetWidth > 400) {
        mode = 'horizontal'
      }
      if (window.innerWidth < 768 && offsetWidth > 400) {
        mode = 'horizontal'
      }
      setInitConfig({ ...initConfig, mode: mode as SettingsState['mode'] })
    })
  }

  useLayoutEffect(() => {
    if (dom.current) {
      window.addEventListener('resize', resize)
      resize()
    }
    return () => {
      window.removeEventListener('resize', resize)
    }
  }, [dom.current])
  const getMenu = () => {
    return Object.keys(menuMap).map(item => <Item key={item}>{menuMap[item]}</Item>)
  }

  const renderChildren = () => {
    const { selectKey } = initConfig
    switch (selectKey) {
      case TabEnum.STAFF:
        return <Staff dataID={dataID} />
      case TabEnum.ORGANIZATION:
        return <Organization dataID={dataID} structureType={structureType} />
      // case TabEnum.ROLE:
      //   return <Role />
      default:
        return null
    }
  }

  return (
    <PageContainer
      title={name}
      fixedHeader
      tabList={[
        { tab: menuMap[TabEnum.STAFF], key: TabEnum.STAFF },
        { tab: menuMap[TabEnum.ORGANIZATION], key: TabEnum.ORGANIZATION }
      ]}
      onTabChange={key =>
        setInitConfig({
          ...initConfig,
          selectKey: key
        })
      }>
      {renderChildren()}
      {/* <GridContent>
        <div
          className={styles.main}
          ref={ref => {
            if (ref) {
              dom.current = ref
            }
          }}>
           */}

      {/* <div className={styles.leftMenu}>
            <Menu
              mode={initConfig.mode}
              selectedKeys={[initConfig.selectKey]}
              onClick={({ key }) => {
                setInitConfig({
                  ...initConfig,
                  selectKey: key as CompanyNameStateKeys
                })
              }}>
              {getMenu()}
            </Menu>
          </div>
          <div className={styles.right}>
            <div className={styles.title}>{menuMap[initConfig.selectKey]}</div>
          </div> */}
      {/* </div>
      </GridContent> */}
    </PageContainer>
  )
}

export default CompanyDetail
