import { connect, useRequest } from 'umi'
import { useEffect } from 'react'
import FormRender, { useForm } from 'form-render'
import { message, Button } from 'antd'
import { addInstitution, updateInstitution } from '@/services/api/institution'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import { ModalType } from '@/utils/enum'
import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import type { ConnectProps } from 'umi'

type CompanyModalProps = ConnectProps & {
  visible: boolean
  setVisible: (visible: boolean) => void
  type: ModalType
  defaultFormData?: API.InstitutionListItem
  reload: () => void
  schema?: Record<string, any> | null
}

const CompanyDrawer: React.FC<CompanyModalProps> = ({
  visible,
  setVisible,
  type,
  defaultFormData,
  schema,
  // pTypeList,
  reload
}) => {
  const form = useForm()
  useEffect(() => {
    if (visible && !schema) {
      dispatch({
        type: 'schemaBase/querySchema',
        payload: {
          columnType: BaseMenuEnum.COMPANY
        }
      })
    }
  }, [visible])
  const { run: tryUpdateInstitution } = useRequest(updateInstitution, {
    manual: true,
    onSuccess: () => {
      message.success('更新成功')
    }
  })
  const { run: tryAddInstitution } = useRequest(addInstitution, {
    manual: true,
    onSuccess: () => {
      message.success('创建成功')
    }
  })

  const onFinish = async (formData, errors) => {
    if (errors?.length) return
    try {
      // 执行表单提交
      if (type === ModalType.ADD) {
        await tryAddInstitution(formData)
      } else {
        await tryUpdateInstitution(formData)
      }
      setVisible(false)
      reload()
      // ref.current?.resetFields()
    } catch (error) {
      message.error(error)
    }
  }

  const onMount = () => {
    // console.log(defaultFormData)
    form.setValues(type === ModalType.ADD ? {} : { ...defaultFormData })
    // form.setValues({ ...defaultFormData })
    // delay().then(() => {
    //   form.setSchemaByPath('projectTypeID', {
    //     enum: pTypeList.map(item => item.value),
    //     enumNames: pTypeList.map(item => item.label)
    //   })
    // })
  }
  return (
    <div>
      <div className="text-xl mb-6">
        {type === ModalType.ADD ? '新增企事业单位' : null}
        {type === ModalType.UPDATE ? '编辑企事业单位' : null}
      </div>
      {schema && <FormRender form={form} schema={schema} onFinish={onFinish} onMount={onMount} />}
      <div className="ml-120px">
        <Button type="primary" onClick={form.submit}>
          提交
        </Button>
      </div>
      {/* <Form>
        {schema && <FormRender form={form} schema={schema} onFinish={onFinish} onMount={onMount} />}
        <div className="ml-120px">
          <Button type="primary" onClick={form.submit}>
            提交
          </Button>
        </div>
      </Form> */}
    </div>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  schema: schemaBase.base[BaseMenuEnum.COMPANY]?.schema
}))(CompanyDrawer)
