import dayjs from 'dayjs'
import ProTable from '@ant-design/pro-table'
import consts from '@/utils/consts'
import { Button } from 'antd'
import { useRef, useState, useEffect } from 'react'
import { connect, history, Link } from 'umi'
import { queryInstitutionList } from '@/services/api/institution'
import type { ProColumnType, ActionType } from '@ant-design/pro-table'
import type { ConnectProps } from 'umi'
import type { ProjectModelState } from '../../model'
import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import { PageContainer } from '@ant-design/pro-layout'
import CompanyDrawer from './components/CompanyDrawer'
import { ModalType } from '@/utils/enum'
import { generateColumns } from '@/utils/util'
import AnimateContent from '@/components/AnimateContent'

type ListProps = ConnectProps & {
  pTypeList: { label: string; value: string }[]
  base: Record<string, any>
}

const CompanyList: React.FC<ListProps> = ({ base, dispatch, pTypeList }) => {
  const tRef = useRef<ActionType>(null)
  const schema = base?.[BaseMenuEnum.COMPANY]?.schema
  useEffect(() => {
    if (!pTypeList.length) {
      dispatch({
        type: 'project/queryProjectTypeList'
      })
    }
    if (!base[BaseMenuEnum.COMPANY]) {
      dispatch({
        type: 'schemaBase/querySchema',
        payload: {
          columnType: BaseMenuEnum.COMPANY
        }
      })
    }
  }, [])
  const [state, setState] = useState({
    params: {
      search: null
    },
    structureType: 1,
    visible: false,
    currentModalType: ModalType.ADD,
    defaultFormData: null
  })
  // const { run: tryDelProject } = useRequest(delProject, {
  //   manual: true,
  //   onSuccess: () => tRef.current?.reload()
  // })

  const goToDetail = params => {
    // return history.push(`/institutions/company/companyname`)
    return history.push({
      pathname: '/institutions/company/detail',
      state: params
    })
  }

  const columns: ProColumnType<API.InstitutionListItem>[] = [
    {
      dataIndex: 'name',
      title: '企事业单位名称',
      render: (name, record) => (
        <span
          onClick={() =>
            goToDetail({ dataID: record.ID, structureType: state.structureType, name: record.name })
          }
          className="text-primary cursor-pointer">
          {name}
        </span>
      )
    },
    {
      dataIndex: 'acronym',
      title: '企事业单位简称'
    },
    {
      dataIndex: 'institutionAcountTotal',
      title: '人员账号'
    },
    {
      dataIndex: 'createdTime',
      title: '创建时间',
      renderText: text => dayjs(text * 1000).format('YYYY-MM-DD')
    },
    // {
    //   dataIndex: 'project_type_id',
    //   title: '项目类型',
    //   filters: true,
    //   filterMultiple: false,
    //   render: (_, record) => <div>{record.project_type.name}</div>,
    //   valueEnum: pTypeList.reduce((prev, curr) => {
    //     const items = { ...prev }
    //     items[curr.value] = {
    //       text: curr.label
    //     }
    //     return items
    //   }, {})
    // },
    {
      dataIndex: 'created',
      title: '创建人'
    },
    {
      title: '操作',
      dataIndex: 'operation',
      render: (_, record) => (
        <div className="divide-x divide-bg-gray-400 flex flex-row">
          <div
            className="pr-2 text-primary cursor-pointer hover:text-hex-967bbd"
            onClick={() => {
              setState({
                ...state,
                visible: true,
                currentModalType: ModalType.UPDATE,
                defaultFormData: record
              })
            }}>
            编辑
          </div>
          {/* <Popconfirm
            title="确认删除吗？"
            okText="确认"
            cancelText="取消"
            onConfirm={() => tryDelProject({ id: record.id })}
          >
            <div className="pl-2 text-hex-fd3995 cursor-pointer hover:text-hex-e7026e">
              <DeleteOutlined />
            </div>
          </Popconfirm> */}
        </div>
      )
    }
  ]

  return (
    <PageContainer title={false}>
      <ProTable<API.InstitutionListItem>
        rowKey="ID"
        params={state.params}
        actionRef={tRef}
        scroll={{ y: document.body.clientHeight - 313 }}
        columns={generateColumns(columns, schema)}
        request={async (params, filter, sorter) => {
          const { code = -1, data: { items = [], total = 0 } = {} } = await queryInstitutionList({
            ...params,
            ...filter,
            ...sorter
          })
          return {
            data: items,
            success: code === consts.RET_CODE.SUCCESS,
            total
          }
        }}
        toolbar={{
          search: {
            onSearch: val => setState({ ...state, params: { ...state.params, search: val } })
          },
          actions: [
            <Button
              type="primary"
              onClick={() =>
                setState({ ...state, visible: true, currentModalType: ModalType.ADD })
              }>
              新建企事业单位
            </Button>
          ]
        }}
        search={false}
      />
      <AnimateContent
        visible={state.visible}
        onVisibleChange={visible => setState({ ...state, visible })}>
        <CompanyDrawer
          type={state.currentModalType}
          defaultFormData={state.defaultFormData}
          pTypeList={pTypeList}
          visible={state.visible}
          reload={() => tRef.current?.reload()}
          setVisible={(visible: boolean) => setState({ ...state, visible })}
        />
      </AnimateContent>
    </PageContainer>
  )
}

export default connect(
  ({ project, schemaBase }: { project: ProjectModelState; schemaBase: SchemaBaseModelState }) => ({
    pTypeList: project.projectTypeList.map(item => ({ label: item.name, value: item.ID })),
    base: schemaBase.base
  })
)(CompanyList)
