import ProTable from '@ant-design/pro-table'
import type { ProColumnType, ActionType } from '@ant-design/pro-table'
import { PageContainer } from '@ant-design/pro-layout'
import { Button } from 'antd'
import consts from '@/utils/consts'
import { useRef, useState, useEffect } from 'react'
import { connect } from 'umi'
import type { ConnectProps } from 'umi'
import type { InstitutionsModelState } from '../model'
// import StaffModal, { ModalType } from './components/StaffModal'
import { queryAcountList } from '@/services/api/institution'
import dayjs from 'dayjs'
import StaffDetail from './components/StaffDetail'
import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import { generateColumns } from '@/utils/util'
import AnimateContent from '@/components/AnimateContent'
import { ModalType } from '@/utils/enum'

type ListProps = ConnectProps & {
  accountTypeList: { label: string; value: string }[]
  schema?: Record<string, any> | null
}

export const genderEum = {
  0: '男',
  1: '女'
}

const CompanyList: React.FC<ListProps> = ({ schema, dispatch, accountTypeList }) => {
  // console.log(accountTypeList)

  const tRef = useRef<ActionType>(null)
  useEffect(() => {
    if (!accountTypeList.length) {
      dispatch({
        type: 'institutions/queryAccountTypeList'
      })
    }
    dispatch({
      type: 'schemaBase/querySchema',
      payload: {
        columnType: BaseMenuEnum.STAFF
      }
    })
  }, [])
  const [state, setState] = useState({
    params: {
      search: null,
      institutionID: null
    },
    title: '',
    visible: false,
    currentModalType: ModalType.ADD,
    defaultFormData: {}
  })

  const columns: ProColumnType<API.AccountListItem>[] = [
    {
      dataIndex: 'account',
      key: 'account',
      title: '账号',
      render: (name, record) => (
        <div
          className="text-primary cursor-pointer hover:text-hex-967bbd"
          onClick={() => {
            setState({
              ...state,
              visible: true,
              currentModalType: ModalType.PREVIEW,
              title: record.name,
              defaultFormData: {
                dataID: record.ID,
                institutionID: record.institution.ID,
                institutionDisable: true,
                hiddenOrganization: true
              }
            })
          }}>
          {name}
        </div>
      )
    },
    {
      dataIndex: 'name',
      key: 'name',
      title: '名称'
    },
    {
      dataIndex: 'password',
      key: 'password',
      title: '密码'
    },
    {
      dataIndex: 'gender',
      key: 'gender',
      title: '性别',
      render: (_, { gender }) => {
        return <span>{genderEum[gender]}</span>
      }
    },
    {
      dataIndex: 'organizationalStructureID',
      key: 'organizationalStructureID',
      title: '组织架构',
      renderText: (_, record) => record.organizationalStructure?.name
    },
    {
      dataIndex: 'institutionID',
      key: 'institutionID',
      title: '所属企事业单位',
      width: 120,
      renderText: (_, record) => record.institution.name
    },
    {
      dataIndex: 'createdTime',
      key: 'createdTime',
      title: '创建时间',
      renderText: text => dayjs(text * 1000).format('YYYY-MM-DD')
    },
    {
      dataIndex: 'created',
      key: 'created',
      title: '创建者'
    },
    {
      dataIndex: 'accountType',
      key: 'accountType',
      title: '账号类型',
      filters: true,
      filterMultiple: false,
      valueEnum: accountTypeList.reduce((prev, curr) => {
        const items = { ...prev }
        items[curr.value] = {
          text: curr.label
        }
        return items
      }, {})
    },
    {
      title: '操作',
      dataIndex: 'operation',
      render: (_, record) => (
        <div className="divide-x divide-bg-gray-400 flex flex-row">
          <div
            className="pr-2 text-primary cursor-pointer hover:text-hex-967bbd"
            onClick={() => {
              // console.log(record)
              setState({
                ...state,
                visible: true,
                currentModalType: ModalType.UPDATE,
                title: record.name,
                defaultFormData: {
                  dataID: record.ID,
                  institutionID: record.institution.ID,
                  institutionDisable: true,
                  hiddenOrganization: true
                }
              })
            }}>
            编辑
          </div>
          {/* <Popconfirm
            title="确认删除吗？"
            okText="确认"
            cancelText="取消"
            onConfirm={() => tryDelProject({ id: record.id })}
          >
            <div className="pl-2 text-hex-fd3995 cursor-pointer hover:text-hex-e7026e">
              <DeleteOutlined />
            </div>
          </Popconfirm> */}
        </div>
      )
    }
  ]

  return (
    <PageContainer title={false}>
      <ProTable<API.AccountListItem>
        rowKey="ID"
        params={state.params}
        actionRef={tRef}
        scroll={{ y: document.body.clientHeight - 313 }}
        columns={generateColumns(columns, schema)}
        request={async (params, filter, sorter) => {
          const { code = -1, data: { items = [], total = 0 } = {} } = await queryAcountList({
            ...params,
            ...filter,
            ...sorter
          })
          return {
            data: items,
            success: code === consts.RET_CODE.SUCCESS,
            total
          }
        }}
        toolbar={{
          search: {
            onSearch: val => setState({ ...state, params: { ...state.params, search: val } })
          },
          actions: [
            <Button
              type="primary"
              onClick={() =>
                setState({
                  ...state,
                  visible: true,
                  currentModalType: ModalType.ADD,
                  title: '',
                  defaultFormData: {
                    ...state.defaultFormData,
                    dataID: null,
                    institutionID: null,
                    institutionDisable: false,
                    hiddenOrganization: true
                  }
                })
              }>
              新建账号
            </Button>
          ]
        }}
        search={false}
      />
      <AnimateContent
        title={
          <>
            {state.currentModalType === ModalType.ADD ? '新增账号' : null}
            {state.currentModalType === ModalType.UPDATE ? `编辑账号(${state.title})` : null}
            {state.currentModalType === ModalType.PREVIEW ? `员工详情(${state.title})` : null}
          </>
        }
        visible={state.visible}
        onVisibleChange={visible => setState({ ...state, visible })}>
        <StaffDetail
          type={state.currentModalType}
          defaultFormData={state.defaultFormData}
          visible={state.visible}
          reload={() => tRef.current?.reload()}
          onVisibleChange={(visible: boolean) => setState({ ...state, visible })}
        />
      </AnimateContent>
    </PageContainer>
  )
}

export default connect(
  ({
    institutions,
    schemaBase
  }: {
    institutions: InstitutionsModelState
    schemaBase: SchemaBaseModelState
  }) => ({
    accountTypeList: institutions.accountType.map(item => ({
      label: item.name,
      value: item.value
    })),
    schema: schemaBase.base[BaseMenuEnum.STAFF]?.schema
  })
)(CompanyList)
