// import { getProjectTypeList } from '@/services/api/project'
// import consts from '@/utils/consts'
import { getAccountTypeList, queryOrganizationalStructureList } from '@/services/api/institution'
import consts from '@/utils/consts'
import type { Effect, Reducer } from 'umi'

export interface InstitutionsModelState {
  list: API.InstitutionListItem[]
  accountType: API.AccountType[]
  organizationType: API.OrganizationalStructureListItem[]
  dataID: string
}

export interface InstitutionsModelType {
  namespace: 'institutions'
  state: InstitutionsModelState
  effects: {
    query: Effect
    queryAccountTypeList: Effect
    queryOrganizationList: Effect
  }
  reducers: {
    save: Reducer<InstitutionsModelState>
    // 启用 immer 之后
    // save: ImmerReducer<ProjectModelState>;
  }
}

const InstitutionsModel: InstitutionsModelType = {
  namespace: 'institutions',
  state: {
    list: [],
    accountType: [],
    organizationType: []
  },
  effects: {
    *queryInstitutionTypeList({ payload }, { call, put }) {
      // const response = yield call(getProjectTypeList, payload)
      // if (response?.code === consts.RET_CODE.SUCCESS) {
      //   yield put({
      //     type: 'save',
      //     payload: {
      //       projectTypeList: response.data
      //     }
      //   })
      // }
    },
    *queryAccountTypeList(_, { call, put }) {
      // console.log('111')

      const response = yield call(getAccountTypeList)
      if (response?.code === consts.RET_CODE.SUCCESS) {
        yield put({
          type: 'save',
          payload: {
            accountType: response.data
          }
        })
      }
    },
    *queryOrganizationList({ payload }, { call, put }) {
      const response = yield call(queryOrganizationalStructureList, payload)
      if (response?.code === consts.RET_CODE.SUCCESS) {
        yield put({
          type: 'save',
          payload: {
            organizationType: response.data
          }
        })
      }
    }
  },
  reducers: {
    save(state, action) {
      return {
        ...state,
        ...action.payload
      }
    }
    // 启用 immer 之后
    // save(state, action) {
    //   state.name = action.payload;
    // },
  }
}

export default InstitutionsModel
