import React, { useState, useEffect } from 'react'
import { TreeSelect } from 'antd'
import { useRequest } from 'umi'
import { queryAcountInstitutionList } from '@/services/api/institution'

const TreeNodeSelect = ({ params, onChange, placeholder = '请选择', ...otherProps }) => {
  const [list, setList] = useState([])
  const { run: tryAcountInstitutionList } = useRequest(
    () => queryAcountInstitutionList({ ...params, pageSize: 125000 }),
    {
      manual: true,
      onSuccess: result => {
        setList(result)
      }
    }
  )

  useEffect(() => {
    tryAcountInstitutionList()
  }, [])
  const onNodeChange = (value, labelList) => {
    onChange?.(value, { value, label: labelList[0] })
  }
  const renderTreeNodes = data =>
    data.map(item => {
      const newItem = { ...item }

      if (newItem.children) {
        newItem.disabled = true
        newItem.children = renderTreeNodes(newItem.children)
        return newItem
      }
      return newItem
    })
  return list?.length ? (
    <TreeSelect
      {...otherProps}
      showSearch
      style={{ width: '100%' }}
      placeholder={placeholder}
      treeNodeFilterProp="title"
      showCheckedStrategy="SHOW_ALL"
      allowClear
      treeDefaultExpandAll
      onChange={(value, labelList, extra) => onNodeChange(value, labelList, extra)}
      treeData={renderTreeNodes(list).filter(item => item.children?.length)}
    />
  ) : null
}

export default TreeNodeSelect
