import { getProjectTypeList } from '@/services/api/project'
import consts from '@/utils/consts'
import type { Effect, Reducer } from 'umi'

export interface ProjectModelState {
  projectTypeList: API.ProjectTypeList
}

export interface ProjectModelType {
  namespace: 'project'
  state: ProjectModelState
  effects: {
    query: Effect
  }
  reducers: {
    save: Reducer<ProjectModelState>
    // 启用 immer 之后
    // save: ImmerReducer<ProjectModelState>;
  }
}

const ProjectModel: ProjectModelType = {
  namespace: 'project',

  state: {
    projectTypeList: []
  },

  effects: {
    *queryProjectTypeList({ payload }, { call, put }) {
      const response = yield call(getProjectTypeList, payload)
      if (response?.code === consts.RET_CODE.SUCCESS) {
        yield put({
          type: 'save',
          payload: {
            projectTypeList: response.data
          }
        })
      }
    }
  },
  reducers: {
    save(state, action) {
      return {
        ...state,
        ...action.payload
      }
    }
    // 启用 immer 之后
    // save(state, action) {
    //   state.name = action.payload;
    // },
  }
}

export default ProjectModel
