import Generator from 'fr-generator'
import React, { useRef, useState, useEffect } from 'react'
import { PageContainer } from '@ant-design/pro-layout'
import { connect, useRequest } from 'umi'
import type { ConnectProps } from 'umi'
import type { RouteComponentProps } from 'react-router'
import type { SchemaBaseModelState } from './model'
import { updateSchema } from '@/services/api/schema'
import { message } from 'antd'
import { menuOptions } from '.'

type DetailProps = RouteComponentProps & ConnectProps

const Detail: React.FC<DetailProps> = ({ dispatch, base, location }) => {
  const {
    query: { columnType, ID }
  } = location

  const genRef = useRef(null)

  // const [schema, setSchema] = useState(
  //   () => (base?.[columnType] && JSON.parse(base?.[columnType]?.schema)) || {}
  // )
  // console.log(base?.[columnType]?.schema)

  const { run: tryUpdateSchema } = useRequest(updateSchema, {
    manual: true,
    onSuccess: result => {
      message.success('更新成功')
      // console.log(genRef.current?.getValue())
      dispatch({
        type: 'schemaBase/changeSchemaByColumnType',
        payload: {
          ID,
          columnType,
          schema: result.schema
        }
      })
    }
  })

  useEffect(() => {
    if (columnType && !base[columnType]) {
      dispatch({
        type: 'schemaBase/querySchema',
        payload: {
          columnType
        }
      })
    }
  }, [columnType])
  return (
    <PageContainer title={menuOptions.find(item => item.value === columnType)?.label + '数据模型'}>
      <div className="bg-white shadow-card p-4" style={{ height: 'calc(100vh - 196px)' }}>
        <Generator
          ref={genRef}
          defaultValue={base?.[columnType]?.schema || {}}
          controlButtons={[true, true]}
          extraButtons={[
            true,
            true,
            true,
            true,
            {
              text: '提交',
              type: 'primary',
              onClick: async () => {
                const newSchema = JSON.stringify(genRef.current?.getValue())

                await tryUpdateSchema({
                  ID,
                  columnType,
                  schema: newSchema
                })
              }
            }
          ]}
        />
      </div>
    </PageContainer>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  base: schemaBase.base
}))(Detail)
