import { PageContainer } from '@ant-design/pro-layout'
import LeftMenu from './components/LeftMenu'
import { useState, useEffect } from 'react'
import FormRender, { useForm } from 'form-render'
import { history, connect } from 'umi'
import type { ConnectProps } from 'umi'
import type { SchemaBaseModelState } from './model'

export enum BaseMenuEnum {
  PROJECT = '1',
  COMPANY = '2',
  STAFF = '3'
}

export const menuOptions = [
  { label: '项目信息', value: BaseMenuEnum.PROJECT },
  { label: '企事业单位信息', value: BaseMenuEnum.COMPANY },
  { label: '人员信息', value: BaseMenuEnum.STAFF }
]
type BaseProps = ConnectProps & {
  base: SchemaBaseModelState
}

const Index: React.FC<BaseProps> = ({ base, dispatch }) => {
  const form = useForm()
  const [state, setState] = useState({
    activeKey: BaseMenuEnum.PROJECT,
    schema: base?.[BaseMenuEnum.PROJECT]?.schema
  })
  const currentSchema = base?.[state.activeKey]

  useEffect(() => {
    if (state.activeKey && !base[state.activeKey]) {
      dispatch({
        type: 'schemaBase/querySchema',
        payload: {
          columnType: state.activeKey
        }
      })
    }
  }, [state.activeKey])

  const gotoDetail = (columnType, ID) => {
    history.push({
      pathname: '/work-setting/schema/detail',
      query: { columnType, ID }
    })
  }

  return (
    <PageContainer title={false}>
      <div className="h-full w-full flex flex-row">
        <LeftMenu
          title="基础数据类别"
          options={menuOptions}
          value={state.activeKey}
          onChange={key => setState({ ...state, activeKey: key })}
        />
        <div className="w-6/7 ml-8 bg-white p-4 shadow-card relative ">
          <div className="flex flex-row-reverse mb-4 w-full">
            <div
              onClick={() => gotoDetail(state.activeKey, currentSchema?.ID)}
              className="w-14px h-14px rounded-1/2 hover:bg-dark-50 hover:cursor-pointer"
            ></div>
          </div>
          <div>{currentSchema && <FormRender form={form} schema={currentSchema?.schema} />}</div>
        </div>
      </div>
    </PageContainer>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  base: schemaBase.base
}))(Index)
