import { getSchemaByColmunType } from '@/services/api/schema'
import consts from '@/utils/consts'
import type { Effect, Reducer } from 'umi'

export interface SchemaBaseModelState {
  base: Record<
    string,
    {
      ID: string
      columnType: number
      schema: string
    }
  >
}

export interface SchemaBaseType {
  namespace: 'schemaBase'
  state: SchemaBaseModelState
  effects: {
    querySchema: Effect
  }
  reducers: {
    save: Reducer<SchemaBaseModelState>
    // 启用 immer 之后
    // save: ImmerReducer<ProjectModelState>;
  }
}

const SchemaBaseModel: SchemaBaseType = {
  namespace: 'schemaBase',

  state: {
    base: {}
  },

  effects: {
    *querySchema({ payload }, { call, put }) {
      const response = yield call(getSchemaByColmunType, payload)
      if (response?.code === consts.RET_CODE.SUCCESS) {
        yield put({
          type: 'save',
          payload: {
            ...response.data?.[0]
          }
        })
      }
    },
    *changeSchemaByColumnType({ payload }, { put }) {
      yield put({
        type: 'save',
        payload
      })
    }
  },
  reducers: {
    save(state, action) {
      return {
        ...state,
        base: { ...state?.base, [action.payload.columnType]: action.payload }
      }
    }

    // 启用 immer 之后
    // save(state, action) {
    //   state.name = action.payload;
    // },
  }
}

export default SchemaBaseModel
