import { request } from 'umi'

/** 获取项目列表 POST /api/project/list */
export async function getProjectList(params: API.ProjectListParams) {
  return request<API.ProjectList>('/project/list', {
    method: 'POST',
    data: {
      ...params
    }
  })
}

/** 获取项目类型列表 POST /api/projectType/list */
export async function getProjectTypeList() {
  return request<API.ProjectTypeList>('/projectType/list', {
    method: 'POST'
  })
}

/** 项目详情 GET /api/project/detail */
export async function getProject(params: API.ProjectDelParams) {
  return request('/project/detail', {
    method: 'GET',
    params
  })
}

/** 删除项目 POST /api/project/delete */
export async function delProject(params: API.ProjectDelParams) {
  return request('/project/delete', {
    method: 'POST',
    data: params
  })
}

/** 更新项目 POST /api/project/update */
export async function updateProject(params: API.ProjectUpdateParams) {
  return request('/project/update', {
    method: 'POST',
    data: params
  })
}
/** 新增项目 POST /api/project/add */
export async function addProject(params: API.ProjectAddParams) {
  return request('/project/add', {
    method: 'POST',
    data: params
  })
}

/** 更新审批流程图 */
export async function addApprovalFlow(params) {
  return request('/approval/update/process', {
    method: 'POST',
    data: params
  })
}

/** 获得审批列表 */
export async function getApprovalList(params: API.ApprovalListParams) {
  return request('/approval/list', {
    method: 'GET',
    params
  })
}

/** 设置审批信息 */
export async function setApproval(params: API.ApprovalSetParams) {
  return request('/project/set/approval', {
    method: 'POST',
    data: params
  })
}

/** 删除审批流程 */
export async function delApproval(params: { ID: string }) {
  return request('/approval/delete', {
    method: 'POST',
    data: params
  })
}
/** 新增审批流程 */
export async function addApproval(params: { name: string }) {
  return request('/approval/add', {
    method: 'POST',
    data: params
  })
}

/** 更新审批流程 */
export async function updateApproval(params: { ID: string; name: string }) {
  return request('/approval/update', {
    method: 'POST',
    data: params
  })
}

/** 设置项目人员 */
export async function setProjectPersonor(params: {
  ID: string
  createdID: string
  reportAccount: string
}) {
  return request('/project/set/personnel', {
    method: 'POST',
    data: params
  })
}
