// @ts-ignore
/* eslint-disable */

declare namespace API {
  type BasicPageParams = {
    /** 页码 */
    current: number
    /** 页数 */
    pageSize: number
  }

  type BasicFetchResult<T> = {
    items: T[]
    total: number
  }

  type ProjectList = BasicFetchResult<ProjectListItem>

  type ProjectListItem = {
    createdTime: string
    name: string
    created: string
    createdID: string
    projectType: ProjectTypeListItem
    ID: string
  }

  type ProjectListParams = BasicPageParams & {
    search?: string
    projectTypeID?: string
  }

  type ProjectDelParams = {
    ID: string
  }

  type ProjectUpdateParams = {
    ID: string
    name: string
    projectTypeID: string
  }
  type ProjectAddParams = Omit<ProjectUpdateParams, 'ID'>

  type ProjectTypeList = ProjectTypeListItem[]

  type ProjectTypeListItem = {
    name: string
    ID: string
    updatedTime: string
    createdTime: string
  }

  /** 事业单位列表 */
  type InstitutionList = BasicFetchResult<InstitutionListItem>

  type InstitutionListItem = {
    name: string
    /** @name 简称 */
    acronym: string
    /** @name 企业代码 */
    enterpriseCode: string
    /** @name 组织结构代码 */
    organizationCode: string
    /** @name 人员账号数量 */
    institutionAccountTotal: number
    bank: string
    bankAccount: string
    phone: string
    address: string
    fax: string
    legalPerson: string
    idCard: string
    createdTime: string
    updatedTime: string
    ID: string
  }

  type InstitutionListParams = BasicPageParams & {
    search?: string
    institutionTypeId?: string
  }

  type InstitutionAddParams = Omit<InstitutionListItem, 'createdTime' | 'updatedTime' | 'ID'>

  type InstitutionUpdateParams = Omit<InstitutionListItem, 'createdTime' | 'updatedTime'>

  /** 账号列表 */
  type AccountList = BasicFetchResult<AccountListItem>

  type AccountListItem = {
    ID: string
    createdTime: number
    accountType: string
    account: string
    name: string
    phone: string
    institution: {
      ID: string
      name: string
    }
    key: string
    value: string
    created: string
    createdID: string
    id: string
    dataID: string
    gender: string
  }

  type AccountListParams = BasicPageParams & {
    search?: string
    /** @name 账号类型(1-企事业账号) ... */
    accountType: number
  }

  type AcountAddParams = {
    /** @name 企事业ID */
    institutionID: string
    /** @name 账号类型(1-企事业账号) ... */
    accountType: string
    account: string
    password: string
    name: string
    phone?: string
    gender: number
  }

  type AcountUpdateParams = Omit<AcountAddParams, 'account' | 'accountType' | 'password'> & {
    ID: string
  }

  type AcountInstitutionParams = {
    name: string
    key: string
    value: string
    children: AccountListItem[]
  }

  type AccountType = {
    value: number
    name: string
  }

  type OrganizationalStructureListParams = {
    structureType: string
    dataID: string
  }

  type OrganizationalStructureListItem = {
    structureType: number
    dataID: string
    name: string
    parentID: string
    ID: string
    accountTotal: number
    sort: number
    id: string
    children: OrganizationalStructureListItem[]
    isLeaf: boolean
  }

  type OrganizationalStructureAddParams = {
    structureType: string
    dataID: string
    name: string
    parentID: string
  }

  type OrganizationalStructureUpdateParams = {
    ID: string
    name: string
  }

  type OrganizationalStructureMoveSortParams = {
    ID: string
    operation: string
  }

  type OrganizationalStructureMoveParams = {
    ID: string
    moveID: string
  }

  type OrganizationalStructureDelParams = {
    ID: string
  }
  type Schema = {
    ID: string
    columnType: number
    schema: string
  }

  type SchemaParams = {
    columnType: number
  }

  type ApprovalItem = {
    ID: string
    name: string
    flowProcess: any
    flowProcessData: any
  }

  type ApprovalList = ApprovalItem[]

  type ApprovalListParams = BasicPageParams & {
    search?: string
  }

  type ApprovalSetParams = {
    ID: string
    accountID: string
    approvalID: string
  }

  type LoginParams = {
    account: string
    password: string
    autoLogin: boolean
    type: string
  }

  type LoginResult = {
    code: number
    msg: number
  }

  type AurrentAccount = {
    ID: string
    createdTime: number
    accountType: string
    account: string
    name: string
    phone: string
    institution: {
      ID: string
      name: string
    }
    created: string
    createdID: string
    id: string
    dataID: string
    gender: string
  }

  type UpdateSettingParams = {
    password: string
    newPassword: string
    confirmPassword: string
  }

  type SettingInfo = {
    name: string
    logo: string
    backstageName: string
    backstageLogo: string
  }
}
